@@ -19,11 +19,11 @@
 #include "global.h"
 #include "pagesize.h"
 
-#include <QtCore/QObject>
-#include <QtCore/QStringList>
-#include <QtCore/QVector>
-#include <QtPrintSupport/QPrinter>
-#include <QtXml/QDomDocument>
+#include <QObject>
+#include <QStringList>
+#include <QVector>
+#include <QPrinter>
+#include <QDomDocument>
 
 #include <QMimeType>
 #include <QUrl>
@@ -48,6 +48,7 @@ class DocumentViewport;
 class EmbeddedFile;
 class ExportFormat;
 class FontInfo;
+class FormField;
 class FormFieldText;
 class FormFieldButton;
 class FormFieldChoice;
@@ -60,6 +61,7 @@ class RenditionAction;
 class SourceReference;
 class View;
 class VisiblePageRect;
+class SignatureInfo;
 
 /** IDs for seaches. Globally defined here. **/
 #define PART_SEARCH_ID 1
@@ -180,7 +182,7 @@ class OKULARCORE_EXPORT DocumentInfo
  *
  * It is designed to keep it detached from the document type (pdf, ps, you
  * name it..) so whenever you want to get some data, it asks its internal
- * generators to do the job and return results in a format-indepedent way.
+ * generators to do the job and return results in a format-independent way.
  *
  * Apart from the generator (the currently running one) the document stores
  * all the Pages ('Page' class) of the current document in a vector and
@@ -419,6 +421,7 @@ class OKULARCORE_EXPORT Document : public QObject
         /**
          * Sets the current document viewport to the given @p page.
          *
+         * @param page The number of the page.
          * @param excludeObserver The observer ids which shouldn't be effected by this change.
          * @param smoothMove Whether the move shall be animated smoothly.
          */
@@ -427,6 +430,7 @@ class OKULARCORE_EXPORT Document : public QObject
         /**
          * Sets the current document viewport to the given @p viewport.
          *
+         * @param viewport The document viewport.
          * @param excludeObserver The observer which shouldn't be effected by this change.
          * @param smoothMove Whether the move shall be animated smoothly.
          */
@@ -481,6 +485,7 @@ class OKULARCORE_EXPORT Document : public QObject
         /**
          * Sends @p requests for pixmap generation.
          *
+         * @param requests the linked list of requests
          * @param reqOptions the options for the request
          *
          * @since 0.7 (KDE 4.1)
@@ -525,7 +530,7 @@ class OKULARCORE_EXPORT Document : public QObject
          * Translates the position of the given @p annotation on the given @p page by a distance @p delta in normalized coordinates.
          *
          * Consecutive translations applied to the same @p annotation are merged together on the undo stack if the
-         * BeingMoved flag is set on the @P annotation.
+         * BeingMoved flag is set on the @p annotation.
          *
          * @since 0.17 (KDE 4.11)
          */
@@ -539,7 +544,7 @@ class OKULARCORE_EXPORT Document : public QObject
          * @p delta2 in normalized coordinates is added to bottom-right.
          *
          * Consecutive adjustments applied to the same @p annotation are merged together on the undo stack if the
-         * BeingResized flag is set on the @P annotation.
+         * BeingResized flag is set on the @p annotation.
          *
          * @since 1.1.0
          */
@@ -579,6 +584,7 @@ class OKULARCORE_EXPORT Document : public QObject
         /**
          * Sets the text selection for the given @p page.
          *
+         * @param page The number of the page.
          * @param rect The rectangle of the selection.
          * @param color The color of the selection.
          */
@@ -624,6 +630,7 @@ class OKULARCORE_EXPORT Document : public QObject
          * Searches the given @p text in the document.
          *
          * @param searchID The unique id for this search request.
+         * @param text The text to be searched.
          * @param fromStart Whether the search should be started at begin of the document.
          * @param caseSensitivity Whether the search is case sensitive.
          * @param type The type of the search. @ref SearchType
@@ -1020,7 +1027,20 @@ class OKULARCORE_EXPORT Document : public QObject
         */
         void reloadDocument() const;
 
+        /**
+         * Returns the part of document covered by the given signature @p info.
+         *
+         * @since 1.7
+         */
+        QByteArray requestSignedRevisionData( const Okular::SignatureInfo &info );
+
     Q_SIGNALS:
+        /**
+         * This signal is emitted whenever the document is about to close.
+         * @since 1.5.3
+         */
+        void aboutToClose();
+
         /**
          * This signal is emitted whenever an action requests a
          * document close operation.
@@ -1114,6 +1134,9 @@ class OKULARCORE_EXPORT Document : public QObject
          * This signal is emitted whenever a source reference with the given parameters has been
          * activated.
          *
+         * \param absFileName absolute name of the file.
+         * \param line line number.
+         * \param col column number.
          * \param handled should be set to 'true' if a slot handles this source reference; the
          *                default action to launch the configured editor will then not be performed
          *                by the document
@@ -1128,19 +1151,19 @@ class OKULARCORE_EXPORT Document : public QObject
         void processMovieAction( const Okular::MovieAction *action );
 
         /**
-         * This signal is emmitted whenever the availability of the undo function changes
+         * This signal is emitted whenever the availability of the undo function changes
          * @since 0.17 (KDE 4.11)
          */
         void canUndoChanged( bool undoAvailable );
 
         /**
-         * This signal is emmitted whenever the availability of the redo function changes
+         * This signal is emitted whenever the availability of the redo function changes
          * @since 0.17 (KDE 4.11)
          */
         void canRedoChanged( bool redoAvailable );
 
         /**
-         * This signal is emmitted whenever the undo history is clean (i.e. the same status the last time it was saved)
+         * This signal is emitted whenever the undo history is clean (i.e. the same status the last time it was saved)
          * @since 1.3
          */
         void undoHistoryCleanChanged( bool clean );
@@ -1153,7 +1176,7 @@ class OKULARCORE_EXPORT Document : public QObject
         void processRenditionAction( const Okular::RenditionAction *action );
 
         /**
-         * This signal is emmitted whenever the contents of the given @p annotation are changed by an undo
+         * This signal is emitted whenever the contents of the given @p annotation are changed by an undo
          * or redo action.
          *
          * The new contents (@p contents), cursor position (@p cursorPos), and anchor position (@p anchorPos) are
@@ -1163,7 +1186,7 @@ class OKULARCORE_EXPORT Document : public QObject
         void annotationContentsChangedByUndoRedo( Okular::Annotation* annotation, const QString & contents, int cursorPos, int anchorPos );
 
         /**
-         * This signal is emmitted whenever the text contents of the given text @p form on the given @p page
+         * This signal is emitted whenever the text contents of the given text @p form on the given @p page
          * are changed by an undo or redo action.
          *
          * The new text contents (@p contents), cursor position (@p cursorPos), and anchor position (@p anchorPos) are
@@ -1173,25 +1196,32 @@ class OKULARCORE_EXPORT Document : public QObject
         void formTextChangedByUndoRedo( int page, Okular::FormFieldText* form, const QString & contents, int cursorPos, int anchorPos );
 
         /**
-         * This signal is emmitted whenever the selected @p choices for the given list @p form on the
+         * This signal is emitted whenever the selected @p choices for the given list @p form on the
          * given @p page are changed by an undo or redo action.
          * @since 0.17 (KDE 4.11)
          */
         void formListChangedByUndoRedo( int page, Okular::FormFieldChoice* form, const QList< int > & choices );
 
         /**
-         * This signal is emmitted whenever the active @p text for the given combo @p form on the
+         * This signal is emitted whenever the active @p text for the given combo @p form on the
          * given @p page is changed by an undo or redo action.
          * @since 0.17 (KDE 4.11)
          */
         void formComboChangedByUndoRedo( int page, Okular::FormFieldChoice* form, const QString & text, int cursorPos, int anchorPos );
 
         /**
-         * This signal is emmitted whenever the state of the specified group of form buttons (@p formButtons) on the
+         * This signal is emitted whenever the state of the specified group of form buttons (@p formButtons) on the
          * given @p page is changed by an undo or redo action.
          * @since 0.17 (KDE 4.11)
          */
         void formButtonsChangedByUndoRedo( int page, const QList< Okular::FormFieldButton* > & formButtons );
+
+        /**
+         * This signal is emitted whenever a FormField was changed programmatically and the
+         * according widget should be updated.
+         * @since 1.4
+         */
+        void refreshFormWidget( Okular::FormField *field );
     private:
         /// @cond PRIVATE
         friend class DocumentPrivate;
@@ -1285,7 +1315,7 @@ class OKULARCORE_EXPORT DocumentViewport
         } rePos;
 
         /**
-         * If 'autoFit.enabled == true' then the page must be autofitted in the viewport.
+         * If 'autoFit.enabled == true' then the page must be autofit in the viewport.
          */
         struct {
             bool enabled;
